@@ -37,14 +37,17 @@ prepare_climate <- function(
   to = '2010-11'
 ){
 
+  # make data.frame
+  climate = data.frame(climate)
+
   # Test for the columns consistensy
   if( !all(c("tmp_min","tmp_max","prcp","srad","frost_days") %in% colnames(climate)) ){
     stop( 'Climate table must include the following columns: tmp_min, tmp_max, prcp, srad, frost_days' )
   }
 
   # Test for NA
-  if( any( is.na(climate) ) ){
-    stop( "Climate table should not contain NA's" )
+  if( any( is.na(climate[c("tmp_min","tmp_max","prcp","srad","frost_days")]) ) ){
+    stop( "Climate table should not contain NAs" )
   }
 
   # prepare the time period
@@ -55,9 +58,6 @@ prepare_climate <- function(
     stop( 'The start date is later than the end date' )
   }
 
-  # make data.frame
-  climate = data.frame(climate)
-
   # Replicate or subset the data
   if( dim(climate)[1] == 12 ){
 
